@@ -1,5 +1,8 @@
 package Net::Douban::Atom;
-our $VERSION = '1.06';
+
+BEGIN {
+    $Net::Douban::Atom::VERSION = '1.07';
+}
 
 use Moose;
 use Carp qw/carp croak/;
@@ -107,28 +110,25 @@ sub search_info {
     return \%search_info;
 }
 
-our $AUTOLOAD;
-
-sub AUTOLOAD {
-
-    #	my $self = shift;
-    #	my $class = ref $self ? ref $self : $self;
-    (my $name = $AUTOLOAD) =~ s/.*:://g;
-    return if $name eq 'DESTROY';
-    my $sub = <<SUB;
-	sub $name {
-		my \$self =  shift;
-		return \$self->get($name);
-	}
-SUB
-    eval($sub);    ## the same as *$name = $sub;
-    goto &$name;
-}
-sub DESTROY { }
+#our $AUTOLOAD;
+#
+#sub AUTOLOAD {
+#
+#    (my $name = $AUTOLOAD) =~ s/.*:://g;
+#    return if $name eq 'DESTROY';
+#    my $sub = <<SUB;
+#	sub $name {
+#		my \$self =  shift;
+#		return \$self->get($name);
+#	}
+#SUB
+#    eval($sub);    ## the same as *$name = $sub;
+#    goto &$name;
+#}
+#sub DESTROY { }
 
 no Moose;
 
-#__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -143,7 +143,7 @@ Net::Douban::Atom - Atom parser
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 	
@@ -198,12 +198,6 @@ XML::Atom::Base::get的重载，当没有NS给出时，尽量‘聪明的’猜
 
 返回根entry，应用与情况为feed的root note是entry，即只是获得单个结果的情况(如获得一部电影信息，获得一个用户的信息等)。尽管这时$feed->whaterver也能获得相当多的结果，但仍然强烈建议使用$feed->entry->whatever来获得对应结果。此外，Net::Douban::Entry提供了比Atom更多的特性
 
-=item B<AUTOLOAD>
-
-	$feed->whatever;
-
-当遇到没有明确定义过的函数时，Net::Douban::Atom内部自动使用$self->get('whatever')
-
 =back
 
 =head1 SEE ALSO
