@@ -1,7 +1,11 @@
 package Net::Douban::Collection;
-our $VERSION = '1.06';
+
+BEGIN {
+    $Net::Douban::Collection::VERSION = '1.07';
+}
 
 use Moose;
+use MooseX::StrictConstructor;
 use Carp qw/carp croak/;
 use Net::Douban::Atom;
 with 'Net::Douban::Roles::More';
@@ -11,25 +15,33 @@ has 'collectionID' => (
     isa => 'Str',
 );
 
+has 'collection_url' => (
+    is      => 'rw',
+    isa     => 'Url',
+    lazy    => 1,
+    default => sub { shift->base_url . '/collection' },
+);
+
 sub get_collection {
     my ($self, %args) = @_;
     $args{collectionID} ||= $self->collectionID;
+    croak "collectionID missing" unless $args{collectionID};
     return Net::Douban::Atom->new(
-        $self->collection_url . "/$args{collectionID}");
+        $self->get($self->collection_url . "/$args{collectionID}"));
 }
 
 sub get_user_collection {
     my ($self, %args) = @_;
     my $uid = delete $args{userID} or croak "userID needed!";
-    exists $args{cat} or croak "cat needed!";
-    return Net::Douban::Atom->new($self->user_url . "/$uid/collection", %args,
-    );
+    exists $args{cat} or croak "cat(category) needed!";
+    return Net::Douban::Atom->new(
+        $self->get($self->user_url . "/$uid/collection", %args));
 }
 
 sub add_collection {
     my ($self, %args) = @_;
     croak "post xml needed" unless exists $args{xml};
-    return $self->post($self->collection_url, $args{xml},);
+    return $self->post($self->collection_url, xml => $args{xml});
 }
 
 sub put_collection {
@@ -37,12 +49,13 @@ sub put_collection {
     $args{collectionID} ||= $self->collectionID;
     croak "put xml needed" unless exists $args{xml};
     return $self->put($self->collection_url . "/$args{collectionID}",
-        $args{xml},);
+        xml => $args{xml},);
 }
 
 sub delete_collection {
     my ($self, %args) = @_;
     $args{collectionID} ||= $self->collectionID;
+    croak "collectionID missing" unless $args{collectionID};
     return $self->delete($self->collection_url . "/$args{collectionID}");
 
 }
@@ -61,7 +74,7 @@ __END__
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -95,7 +108,7 @@ Interface to douban.com API collection section
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://douban.com/service/apidoc>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://www.douban.com/service/apidoc/reference/collection>
 
 =head1 AUTHOR
 
