@@ -1,7 +1,11 @@
 package Net::Douban::DBSubject;
-our $VERSION = '1.06';
+
+BEGIN {
+    $Net::Douban::DBSubject::VERSION = '1.07';
+}
 
 use Moose;
+use MooseX::StrictConstructor;
 extends 'Net::Douban::Entry';
 
 sub BUILD {
