@@ -1,10 +1,14 @@
 package Net::Douban::User;
-our $VERSION = '1.06';
+
+BEGIN {
+    $Net::Douban::User::VERSION = '1.07';
+}
 
 use Moose;
+with 'Net::Douban::Roles::More';
 use Net::Douban::Atom;
 use Carp qw/carp croak/;
-with 'Net::Douban::Roles::More';
+use MooseX::StrictConstructor;
 
 has 'userID' => (is => 'rw', isa => 'Str',);
 
@@ -56,7 +60,7 @@ Net::Douban::User
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -72,6 +76,7 @@ version 1.06
 	$atom = $user->get_user;
 	$atom = $user->get_friends;
 	$atom = $user->get_contacts;
+    $atom = $user->search(q => 'douban', start_index => 5, max_results => 10);
 
 =head1 DESCRIPTION
 
@@ -79,6 +84,8 @@ Interface to douban.com API User section
 
 =head1 METHODS
 
+Those methods return a Net::Douban::Atom object which can be use to get data conveniently
+
 =over
 
 =item B<get_user>
@@ -95,7 +102,7 @@ Interface to douban.com API User section
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> B<douban.com/service/apidoc>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> B<http://www.douban.com/service/apidoc/reference/user>
 
 =head1 AUTHOR
 
